;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "presentation" "20260131.2112"
  "Scale text globally and adjust UI for presentations."
  '((emacs  "24.4")
    (compat "30"))
  :url "https://github.com/zonuexe/emacs-presentation-mode"
  :commit "5393ea474d76a9d529d27fb1d6185c015e34368c"
  :revdesc "5393ea474d76"
  :keywords '("environment" "faces" "frames")
  :authors '(("USAMI Kenta" . "tadsan@zonu.me"))
  :maintainers '(("USAMI Kenta" . "tadsan@zonu.me")))
